@@ -1355,8 +1355,9 @@ class Insight_Definition:
                 definition = r.json()
                 insight_definition = Insight_Definition(self._env, self._token, definition)
                 insight_definition.delete()
-            except:
+            except Exception as e:
                 logging.info("{} card not found... creating new one".format(card_slug))
+                logging.info("{}".format(e.with_traceback()))
 
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/clone"
